#
# spec file for package log4cpp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sonum 5

Name:           log4cpp
Version:        1.1.4
Release:        1.3
Summary:        C++ logging library
License:        LGPL-2.1-only
Group:          Development/Languages/C and C++
URL:            https://log4cpp.sourceforge.net/
Source:         https://downloads.sourceforge.net/project/log4cpp/log4cpp-1.1.x%20%28new%29/log4cpp-1.1/log4cpp-%{version}.tar.gz
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkg-config

%define libname lib%{name}%{sonum}

%description
Log for C++ is a library of classes for flexible logging to files,
syslog, and other destinations. It is modeled after the Log for Java
library and stays as close to its API as is reasonable.

%package -n %{libname}
Summary:        Logging for C++
Group:          System/Libraries

%description -n %{libname}
Logging facilities providing library.

%package devel
Summary:        Development tools for Log for C++
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
The %{name}-devel package contains the static libraries and header files
needed for development with %{name}.

%package doc
Summary:        HTML formatted API documention for Log for C++
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
The %{name}-doc package contains HTML formatted API documention generated by
the popular doxygen documentation generation tool.

%prep
%setup -q -n %{name}

%build
%configure --enable-doxygen --disable-static
%make_build

%install
%make_install mandir="%{buildroot}/%{_mandir}" docdir="%{buildroot}/%{_docdir}/%{name}"
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes -s %{buildroot}/%{_docdir}/%{name}/api

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%{_libdir}/*.so.%{sonum}*

%files devel
%{_includedir}/%{name}
%{_mandir}/man3/%{name}*.3%{?ext_man}
%{_bindir}/%{name}-config
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc
%dir %{_datadir}/aclocal
%attr(644,root,root) %{_datadir}/aclocal/%{name}.m4

%files doc
%doc AUTHORS ChangeLog NEWS README THANKS
%doc %{_docdir}/%{name}
%license COPYING

%changelog
* Wed Jan  3 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to version 1.1.4
  * fix for bug 152: use timespec and clock_settime for c++11 and
    higher; use stime for glibc version lower than 2.31; none for
    other cases
  * Replace obsolete auto_ptr removed in C++17 with newer
    unique_ptr since C++11
  * Replace older Non-throwing dynamic exception specification
    throw() removed in C++20 with newer noexcept since C++11
  * Patch #49 C99 compatibility fix for snprintf configure check
  * va_copy is here since c++11; fallback to simple copy if
    standard is not specified or less than c++11
- Replace _service with full URL in Source
* Fri Dec 28 2018 Jan Engelhardt <jengelh@inai.de>
- Wrap description again.
- Replace %%__-type macro indirections.
* Wed Dec 19 2018 marec@detebe.org
- update to version 1.1.3
  * no upstream changelog
- drop fix_sle11_build.patch, no longer needed
* Mon Oct 10 2016 adam.majer@suse.de
- update to version 1.1.2rc3
  + fix std::terminate() call on bad category name component count
    in PatternLayout
  + fix std::terminate() call on bad root category priority name
    in config file
  + remove RollingFileAppend prints log name to std::cout
- fix_sle11_build.patch: fix building on SLE11
* Sat Jul  2 2016 jengelh@inai.de
- Fixup groups and do not waste time building static libs that
  do not get shipped.
* Thu Jun 30 2016 i@marguerite.su
- update version 1.1.2rc2
  * no upstream changelog
* Sat Aug 22 2015 i@marguerite.su
- update version 1.1.2rc1
  * Small fixes, DailyRollingFile appender, tests,
    options to disable support for smtp and syslog
* Fri Dec  6 2013 avvissu@yandex.ru
- update to 1.1.1
* Sun Jan 13 2013 sleep_walker@suse.cz
- remove dependency on neexisting package log4cpp
* Sun Jan 13 2013 sleep_walker@suse.cz
- update to 1.1
- remove log4cpp_inclusion_fixes.patch which reached upstream
- rework the spec
  - change manual creation of symlinks with %%fdupes
  - change package name to log4cpp, library is subpackage (now
    liblog4cpp5)
* Thu Jul 19 2012 rob.verduijn@gmail.com
- conflicts fixed for opensuse 12.1
* Wed Jul 18 2012 rob.verduijn@gmail.com
- fixed some more rpmlint badness
* Wed Jul 18 2012 rob.verduijn@gmail.com
- fixed duplicate files
* Wed Jul 18 2012 rob.verduijn@gmail.com
- Fixed directory not owned in specfile
* Tue Aug 30 2011 alexandre@exatati.com.br
- Fix spec file.
* Tue Jan 13 2009 bbrunner@suse.de
- Initial package.
